@@ -15,6 +15,8 @@ my $encoding = term_encoding();
 binmode *STDIN,  ":encoding(${encoding})";
 binmode *STDOUT, ":encoding(${encoding})";
 
+my $history_file_name = 'suddenly.hist';
+
 my $c = Caroline->new(
     completion_callback => sub {
         my ($line) = @_;
@@ -30,11 +32,18 @@ my $c = Caroline->new(
         }
         return;
     },
-    history_max_len => 3,
+    history_max_len => 30,
 );
+if (-f $history_file_name) {
+    $c->read_history_file($history_file_name)
+        or warn "Cannot read $history_file_name: $!";
+}
 while (defined(my $line = $c->readline('hello> '))) {
     if ($line =~ /\S/) {
         print sudden_death($line), "\n";
         $c->history_add($line);
     }
 }
+END {
+    $c->write_history_file($history_file_name);
+}
